(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('yt-player'), require('rxjs')) :
    typeof define === 'function' && define.amd ? define('yt-player-angular', ['exports', '@angular/core', 'yt-player', 'rxjs'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['yt-player-angular'] = {}, global.ng.core, global.YtPlayer, global.rxjs));
}(this, (function (exports, i0, YtPlayer, rxjs) { 'use strict';

    function _interopNamespace(e) {
        if (e && e.__esModule) { return e; } else {
            var n = Object.create(null);
            if (e) {
                Object.keys(e).forEach(function (k) {
                    if (k !== 'default') {
                        var d = Object.getOwnPropertyDescriptor(e, k);
                        Object.defineProperty(n, k, d.get ? d : {
                            enumerable: true,
                            get: function () {
                                return e[k];
                            }
                        });
                    }
                });
            }
            n['default'] = e;
            return Object.freeze(n);
        }
    }

    var YtPlayer__namespace = /*#__PURE__*/_interopNamespace(YtPlayer);

    var YtPlayerAdapterModule = /** @class */ (function () {
        function YtPlayerAdapterModule() {
        }
        return YtPlayerAdapterModule;
    }());
    YtPlayerAdapterModule.decorators = [
        { type: i0.NgModule, args: [{},] }
    ];

    (function (StateChangeType) {
        StateChangeType[StateChangeType["Error"] = 0] = "Error";
        StateChangeType[StateChangeType["Unplayable"] = 1] = "Unplayable";
        StateChangeType[StateChangeType["Unstarted"] = 2] = "Unstarted";
        StateChangeType[StateChangeType["Ended"] = 3] = "Ended";
        StateChangeType[StateChangeType["Started"] = 4] = "Started";
        StateChangeType[StateChangeType["PlaybackProgress"] = 5] = "PlaybackProgress";
        StateChangeType[StateChangeType["Paused"] = 6] = "Paused";
        StateChangeType[StateChangeType["Buffering"] = 7] = "Buffering";
        StateChangeType[StateChangeType["Cued"] = 8] = "Cued";
        StateChangeType[StateChangeType["QualityChanged"] = 9] = "QualityChanged";
        StateChangeType[StateChangeType["RateChanged"] = 10] = "RateChanged";
    })(exports.StateChangeType || (exports.StateChangeType = {}));

    var EventsRegistry = /** @class */ (function () {
        function EventsRegistry(ngZone) {
            var _this = this;
            this.ngZone = ngZone;
            this.stateChange$ = new rxjs.Subject();
            this.eventHandlers = new Map([
                ["error", function (err) { return _this.broadcastStatusChange(exports.StateChangeType.Error, err); }],
                [
                    "unplayable",
                    function (videoId) { return _this.broadcastStatusChange(exports.StateChangeType.Unplayable, videoId); }
                ],
                ["unstarted", function () { return _this.broadcastStatusChange(exports.StateChangeType.Unstarted); }],
                ["ended", function () { return _this.broadcastStatusChange(exports.StateChangeType.Ended); }],
                ["playing", function () { return _this.broadcastStatusChange(exports.StateChangeType.Started); }],
                ["paused", function () { return _this.broadcastStatusChange(exports.StateChangeType.Paused); }],
                ["buffering", function () { return _this.broadcastStatusChange(exports.StateChangeType.Buffering); }],
                ["cued", function () { return _this.broadcastStatusChange(exports.StateChangeType.Cued); }],
                [
                    "playbackQualityChange",
                    function (quality) { return _this.broadcastStatusChange(exports.StateChangeType.QualityChanged, quality); }
                ],
                [
                    "playbackRateChange",
                    function (rate) { return _this.broadcastStatusChange(exports.StateChangeType.RateChanged, rate); }
                ],
                [
                    "timeupdate",
                    function (time) { return _this.broadcastStatusChange(exports.StateChangeType.PlaybackProgress, time); }
                ]
            ]);
        }
        EventsRegistry.prototype.register = function (player) {
            this.eventHandlers.forEach(function (eventHandler, eventName) {
                player.on(eventName, eventHandler);
            });
        };
        EventsRegistry.prototype.broadcastStatusChange = function (type, payload) {
            var _this = this;
            this.ngZone.run(function () { return _this.stateChange$.next({ type: type, payload: payload }); });
        };
        return EventsRegistry;
    }());
    EventsRegistry.ɵprov = i0.ɵɵdefineInjectable({ factory: function EventsRegistry_Factory() { return new EventsRegistry(i0.ɵɵinject(i0.NgZone)); }, token: EventsRegistry, providedIn: YtPlayerAdapterModule });
    EventsRegistry.decorators = [
        { type: i0.Injectable, args: [{ providedIn: YtPlayerAdapterModule },] }
    ];
    EventsRegistry.ctorParameters = function () { return [
        { type: i0.NgZone }
    ]; };

    var YtPlayerService = /** @class */ (function () {
        function YtPlayerService(eventsRegistry) {
            this.eventsRegistry = eventsRegistry;
        }
        Object.defineProperty(YtPlayerService.prototype, "stateChange$", {
            get: function () { return this.eventsRegistry.stateChange$.asObservable(); },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(YtPlayerService.prototype, "destroyed", {
            get: function () { return this.player.destroyed; },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(YtPlayerService.prototype, "videoId", {
            get: function () { return this.player.videoId; },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(YtPlayerService.prototype, "player", {
            get: function () { return this.ytPlayer; },
            set: function (value) { this.ytPlayer = value; },
            enumerable: false,
            configurable: true
        });
        YtPlayerService.prototype.init = function (htmlId, playerOptions) {
            this.setUpPlayer(htmlId, playerOptions);
            this.eventsRegistry.register(this.player);
        };
        YtPlayerService.prototype.load = function (videoId) {
            var autoplay = this.playerOptions && this.playerOptions.autoplay;
            this.player.load(videoId, autoplay);
        };
        YtPlayerService.prototype.play = function () {
            this.player.play();
        };
        YtPlayerService.prototype.pause = function () {
            this.player.pause();
        };
        YtPlayerService.prototype.stop = function () {
            this.player.stop();
        };
        YtPlayerService.prototype.seek = function (seconds) {
            this.player.seek(seconds);
        };
        YtPlayerService.prototype.setVolume = function (value) {
            if (value > 100) {
                console.warn("Provided value " + value + " exceeds max value. 100 used instead");
            }
            this.player.setVolume(value);
        };
        YtPlayerService.prototype.getVolume = function () {
            return this.player.getVolume();
        };
        YtPlayerService.prototype.mute = function () {
            this.player.mute();
        };
        YtPlayerService.prototype.unMute = function () {
            this.player.unMute();
        };
        YtPlayerService.prototype.isMuted = function () {
            return this.player.isMuted();
        };
        YtPlayerService.prototype.setSize = function (width, height) {
            this.player.setSize(width, height);
        };
        YtPlayerService.prototype.setPlaybackRate = function (rate) {
            this.player.setPlaybackRate(rate);
        };
        YtPlayerService.prototype.setPlaybackQuality = function (sugestedQuality) {
            this.player.setPlaybackQuality(sugestedQuality);
        };
        YtPlayerService.prototype.getPlaybackRate = function () {
            return this.player.getPlaybackRate();
        };
        YtPlayerService.prototype.getAvailablePlaybackRates = function () {
            return this.player.getAvailablePlaybackRates();
        };
        YtPlayerService.prototype.getDuration = function () {
            return this.player.getDuration();
        };
        YtPlayerService.prototype.getBufferingProgress = function () {
            return this.player.getProgress();
        };
        YtPlayerService.prototype.getState = function () {
            return this.player.getState();
        };
        YtPlayerService.prototype.getCurrentTime = function () {
            return this.player.getCurrentTime();
        };
        YtPlayerService.prototype.destroy = function () {
            this.player.destroy();
        };
        YtPlayerService.prototype.setUpPlayer = function (htmlId, playerOptions) {
            this.playerOptions = playerOptions;
            this.player = new YtPlayer__namespace(htmlId, playerOptions);
        };
        return YtPlayerService;
    }());
    YtPlayerService.ɵprov = i0.ɵɵdefineInjectable({ factory: function YtPlayerService_Factory() { return new YtPlayerService(i0.ɵɵinject(EventsRegistry)); }, token: YtPlayerService, providedIn: YtPlayerAdapterModule });
    YtPlayerService.decorators = [
        { type: i0.Injectable, args: [{ providedIn: YtPlayerAdapterModule },] }
    ];
    YtPlayerService.ctorParameters = function () { return [
        { type: EventsRegistry }
    ]; };

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */
    /* global Reflect, Promise */
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b)
                if (Object.prototype.hasOwnProperty.call(b, p))
                    d[p] = b[p]; };
        return extendStatics(d, b);
    };
    function __extends(d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }
    var __assign = function () {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p))
                        t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };
    function __rest(s, e) {
        var t = {};
        for (var p in s)
            if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                t[p] = s[p];
        if (s != null && typeof Object.getOwnPropertySymbols === "function")
            for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                    t[p[i]] = s[p[i]];
            }
        return t;
    }
    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
            r = Reflect.decorate(decorators, target, key, desc);
        else
            for (var i = decorators.length - 1; i >= 0; i--)
                if (d = decorators[i])
                    r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }
    function __param(paramIndex, decorator) {
        return function (target, key) { decorator(target, key, paramIndex); };
    }
    function __metadata(metadataKey, metadataValue) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
            return Reflect.metadata(metadataKey, metadataValue);
    }
    function __awaiter(thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try {
                step(generator.next(value));
            }
            catch (e) {
                reject(e);
            } }
            function rejected(value) { try {
                step(generator["throw"](value));
            }
            catch (e) {
                reject(e);
            } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    }
    function __generator(thisArg, body) {
        var _ = { label: 0, sent: function () { if (t[0] & 1)
                throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function () { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f)
                throw new TypeError("Generator is already executing.");
            while (_)
                try {
                    if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done)
                        return t;
                    if (y = 0, t)
                        op = [op[0] & 2, t.value];
                    switch (op[0]) {
                        case 0:
                        case 1:
                            t = op;
                            break;
                        case 4:
                            _.label++;
                            return { value: op[1], done: false };
                        case 5:
                            _.label++;
                            y = op[1];
                            op = [0];
                            continue;
                        case 7:
                            op = _.ops.pop();
                            _.trys.pop();
                            continue;
                        default:
                            if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                                _ = 0;
                                continue;
                            }
                            if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) {
                                _.label = op[1];
                                break;
                            }
                            if (op[0] === 6 && _.label < t[1]) {
                                _.label = t[1];
                                t = op;
                                break;
                            }
                            if (t && _.label < t[2]) {
                                _.label = t[2];
                                _.ops.push(op);
                                break;
                            }
                            if (t[2])
                                _.ops.pop();
                            _.trys.pop();
                            continue;
                    }
                    op = body.call(thisArg, _);
                }
                catch (e) {
                    op = [6, e];
                    y = 0;
                }
                finally {
                    f = t = 0;
                }
            if (op[0] & 5)
                throw op[1];
            return { value: op[0] ? op[1] : void 0, done: true };
        }
    }
    var __createBinding = Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        Object.defineProperty(o, k2, { enumerable: true, get: function () { return m[k]; } });
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    });
    function __exportStar(m, o) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(o, p))
                __createBinding(o, m, p);
    }
    function __values(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m)
            return m.call(o);
        if (o && typeof o.length === "number")
            return {
                next: function () {
                    if (o && i >= o.length)
                        o = void 0;
                    return { value: o && o[i++], done: !o };
                }
            };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    }
    function __read(o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m)
            return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
                ar.push(r.value);
        }
        catch (error) {
            e = { error: error };
        }
        finally {
            try {
                if (r && !r.done && (m = i["return"]))
                    m.call(i);
            }
            finally {
                if (e)
                    throw e.error;
            }
        }
        return ar;
    }
    function __spread() {
        for (var ar = [], i = 0; i < arguments.length; i++)
            ar = ar.concat(__read(arguments[i]));
        return ar;
    }
    function __spreadArrays() {
        for (var s = 0, i = 0, il = arguments.length; i < il; i++)
            s += arguments[i].length;
        for (var r = Array(s), k = 0, i = 0; i < il; i++)
            for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
                r[k] = a[j];
        return r;
    }
    ;
    function __await(v) {
        return this instanceof __await ? (this.v = v, this) : new __await(v);
    }
    function __asyncGenerator(thisArg, _arguments, generator) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var g = generator.apply(thisArg, _arguments || []), i, q = [];
        return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
        function verb(n) { if (g[n])
            i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
        function resume(n, v) { try {
            step(g[n](v));
        }
        catch (e) {
            settle(q[0][3], e);
        } }
        function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
        function fulfill(value) { resume("next", value); }
        function reject(value) { resume("throw", value); }
        function settle(f, v) { if (f(v), q.shift(), q.length)
            resume(q[0][0], q[0][1]); }
    }
    function __asyncDelegator(o) {
        var i, p;
        return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
        function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: n === "return" } : f ? f(v) : v; } : f; }
    }
    function __asyncValues(o) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var m = o[Symbol.asyncIterator], i;
        return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
        function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
        function settle(resolve, reject, d, v) { Promise.resolve(v).then(function (v) { resolve({ value: v, done: d }); }, reject); }
    }
    function __makeTemplateObject(cooked, raw) {
        if (Object.defineProperty) {
            Object.defineProperty(cooked, "raw", { value: raw });
        }
        else {
            cooked.raw = raw;
        }
        return cooked;
    }
    ;
    var __setModuleDefault = Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    };
    function __importStar(mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    }
    function __importDefault(mod) {
        return (mod && mod.__esModule) ? mod : { default: mod };
    }
    function __classPrivateFieldGet(receiver, privateMap) {
        if (!privateMap.has(receiver)) {
            throw new TypeError("attempted to get private field on non-instance");
        }
        return privateMap.get(receiver);
    }
    function __classPrivateFieldSet(receiver, privateMap, value) {
        if (!privateMap.has(receiver)) {
            throw new TypeError("attempted to set private field on non-instance");
        }
        privateMap.set(receiver, value);
        return value;
    }

    var IdGeneratorService = /** @class */ (function () {
        function IdGeneratorService() {
            this.charCodes = { a: 65, z: 90 };
            this.idLength = 8;
        }
        IdGeneratorService.prototype.generate = function () {
            var _this = this;
            return __spread(Array(this.idLength).keys()).reduce(function (acc) { return "" + acc + _this.getRandomLetter(); }, '');
        };
        IdGeneratorService.prototype.getRandomLetter = function () {
            var charCode = this.getRandomIntInRange(this.charCodes.a, this.charCodes.z);
            return String.fromCharCode(charCode);
        };
        IdGeneratorService.prototype.getRandomIntInRange = function (min, max) {
            return Math.floor(Math.random() * (max - min + 1)) + min;
        };
        return IdGeneratorService;
    }());
    IdGeneratorService.ɵprov = i0.ɵɵdefineInjectable({ factory: function IdGeneratorService_Factory() { return new IdGeneratorService(); }, token: IdGeneratorService, providedIn: "root" });
    IdGeneratorService.decorators = [
        { type: i0.Injectable, args: [{ providedIn: 'root' },] }
    ];

    var QueueService = /** @class */ (function () {
        function QueueService() {
            this.queue = new Map();
        }
        QueueService.prototype.enqueue = function (task) {
            var key = this.generateKey();
            this.addTask(key, task);
        };
        QueueService.prototype.dequeue = function () {
            var task = this.getAndRemoveFromQueue();
            this.execute(task);
        };
        QueueService.prototype.addTask = function (key, task) {
            this.queue.set(key, task);
        };
        QueueService.prototype.generateKey = function () {
            return this.queue.size + 1;
        };
        QueueService.prototype.getAndRemoveFromQueue = function () {
            var latestKey = this.queue.size;
            var task = this.queue.get(latestKey);
            this.queue.delete(latestKey);
            return task;
        };
        QueueService.prototype.execute = function (task) {
            if (task && typeof task === 'function') {
                task();
            }
        };
        return QueueService;
    }());
    QueueService.ɵprov = i0.ɵɵdefineInjectable({ factory: function QueueService_Factory() { return new QueueService(); }, token: QueueService, providedIn: "root" });
    QueueService.decorators = [
        { type: i0.Injectable, args: [{ providedIn: 'root' },] }
    ];

    var YtPlayerComponent = /** @class */ (function () {
        function YtPlayerComponent(ytPlayerService, idGeneratorService, queueService) {
            this.ytPlayerService = ytPlayerService;
            this.idGeneratorService = idGeneratorService;
            this.queueService = queueService;
            this.stateChange = new i0.EventEmitter();
            this.errorMessage = 'Player not initialized. Did you specify [videoId] input property of yt-player-component?';
        }
        YtPlayerComponent.prototype.ngOnInit = function () {
            this.setUpElementRefId();
            this.dequeuePlayerInitialization();
            this.loadVideo();
            this.subscribeToStateChanges();
        };
        YtPlayerComponent.prototype.ngOnChanges = function () {
            if (!this.videoIdIsDefined()) {
                return;
            }
            else if (this.elementRefIdIsDefined()) {
                this.reloadVideo();
            }
            else {
                this.enqueuePlayerInitialization();
            }
        };
        YtPlayerComponent.prototype.ngOnDestroy = function () {
            this.ytPlayerService.destroy();
            this.stateChangeSubscription.unsubscribe();
        };
        YtPlayerComponent.prototype.setUpElementRefId = function () {
            var id = this.idGeneratorService.generate();
            this.ytHtmlElementHook.nativeElement.setAttribute('id', id);
        };
        YtPlayerComponent.prototype.videoIdIsDefined = function () {
            return !!this.videoId;
        };
        YtPlayerComponent.prototype.elementRefIdIsDefined = function () {
            return (this.ytHtmlElementHook.nativeElement &&
                this.ytHtmlElementHook.nativeElement.getAttribute('id'));
        };
        YtPlayerComponent.prototype.initializePlayer = function () {
            var id = this.ytHtmlElementHook.nativeElement.getAttribute('id');
            this.ytPlayerService.init("#" + id, this.options);
        };
        YtPlayerComponent.prototype.loadVideo = function () {
            try {
                this.ytPlayerService.load(this.videoId);
            }
            catch (err) {
                console.error(this.errorMessage);
            }
        };
        YtPlayerComponent.prototype.reloadVideo = function () {
            this.ytPlayerService.destroy();
            this.initializePlayer();
            this.loadVideo();
        };
        YtPlayerComponent.prototype.enqueuePlayerInitialization = function () {
            var _this = this;
            this.queueService.enqueue(function () { return _this.initializePlayer(); });
        };
        YtPlayerComponent.prototype.dequeuePlayerInitialization = function () {
            this.queueService.dequeue();
        };
        YtPlayerComponent.prototype.subscribeToStateChanges = function () {
            var _this = this;
            this.stateChangeSubscription = this.ytPlayerService.stateChange$.subscribe(function (stateChange) { return _this.stateChange.emit(stateChange); });
        };
        return YtPlayerComponent;
    }());
    YtPlayerComponent.decorators = [
        { type: i0.Component, args: [{
                    selector: 'yt-player',
                    template: "\n    <div #ytHtmlElementHook></div>\n  "
                },] }
    ];
    YtPlayerComponent.ctorParameters = function () { return [
        { type: YtPlayerService },
        { type: IdGeneratorService },
        { type: QueueService }
    ]; };
    YtPlayerComponent.propDecorators = {
        videoId: [{ type: i0.Input }],
        options: [{ type: i0.Input }],
        stateChange: [{ type: i0.Output }],
        ytHtmlElementHook: [{ type: i0.ViewChild, args: ['ytHtmlElementHook', { static: true },] }]
    };

    var YtPlayerAngularModule = /** @class */ (function () {
        function YtPlayerAngularModule() {
        }
        return YtPlayerAngularModule;
    }());
    YtPlayerAngularModule.decorators = [
        { type: i0.NgModule, args: [{
                    imports: [YtPlayerAdapterModule],
                    declarations: [YtPlayerComponent],
                    exports: [YtPlayerComponent]
                },] }
    ];

    (function (PlayerState) {
        PlayerState[PlayerState["Unstarted"] = 0] = "Unstarted";
        PlayerState[PlayerState["Ended"] = 1] = "Ended";
        PlayerState[PlayerState["Playing"] = 2] = "Playing";
        PlayerState[PlayerState["Paused"] = 3] = "Paused";
        PlayerState[PlayerState["Buffering"] = 4] = "Buffering";
        PlayerState[PlayerState["Cued"] = 5] = "Cued";
    })(exports.PlayerState || (exports.PlayerState = {}));

    (function (PlaybackQuality) {
        PlaybackQuality["Small"] = "small";
        PlaybackQuality["Medium"] = "medium";
        PlaybackQuality["Large"] = "large";
        PlaybackQuality["Hd720"] = "hd720";
        PlaybackQuality["Hd1080"] = "hd1080";
        PlaybackQuality["HighRes"] = "highres";
        PlaybackQuality["Default"] = "default";
    })(exports.PlaybackQuality || (exports.PlaybackQuality = {}));

    /*
     * Public API Surface of yt-player-angular
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.YtPlayerAngularModule = YtPlayerAngularModule;
    exports.YtPlayerComponent = YtPlayerComponent;
    exports.YtPlayerService = YtPlayerService;
    exports.ɵa = YtPlayerAdapterModule;
    exports.ɵb = EventsRegistry;
    exports.ɵc = IdGeneratorService;
    exports.ɵd = QueueService;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=yt-player-angular.umd.js.map
