import { NgModule, ɵɵdefineInjectable, ɵɵinject, NgZone, Injectable, EventEmitter, Component, Input, Output, ViewChild } from '@angular/core';
import * as YtPlayer from 'yt-player';
import { Subject } from 'rxjs';

class YtPlayerAdapterModule {
}
YtPlayerAdapterModule.decorators = [
    { type: NgModule, args: [{},] }
];

var StateChangeType;
(function (StateChangeType) {
    StateChangeType[StateChangeType["Error"] = 0] = "Error";
    StateChangeType[StateChangeType["Unplayable"] = 1] = "Unplayable";
    StateChangeType[StateChangeType["Unstarted"] = 2] = "Unstarted";
    StateChangeType[StateChangeType["Ended"] = 3] = "Ended";
    StateChangeType[StateChangeType["Started"] = 4] = "Started";
    StateChangeType[StateChangeType["PlaybackProgress"] = 5] = "PlaybackProgress";
    StateChangeType[StateChangeType["Paused"] = 6] = "Paused";
    StateChangeType[StateChangeType["Buffering"] = 7] = "Buffering";
    StateChangeType[StateChangeType["Cued"] = 8] = "Cued";
    StateChangeType[StateChangeType["QualityChanged"] = 9] = "QualityChanged";
    StateChangeType[StateChangeType["RateChanged"] = 10] = "RateChanged";
})(StateChangeType || (StateChangeType = {}));

class EventsRegistry {
    constructor(ngZone) {
        this.ngZone = ngZone;
        this.stateChange$ = new Subject();
        this.eventHandlers = new Map([
            ["error", err => this.broadcastStatusChange(StateChangeType.Error, err)],
            [
                "unplayable",
                videoId => this.broadcastStatusChange(StateChangeType.Unplayable, videoId)
            ],
            ["unstarted", () => this.broadcastStatusChange(StateChangeType.Unstarted)],
            ["ended", () => this.broadcastStatusChange(StateChangeType.Ended)],
            ["playing", () => this.broadcastStatusChange(StateChangeType.Started)],
            ["paused", () => this.broadcastStatusChange(StateChangeType.Paused)],
            ["buffering", () => this.broadcastStatusChange(StateChangeType.Buffering)],
            ["cued", () => this.broadcastStatusChange(StateChangeType.Cued)],
            [
                "playbackQualityChange",
                quality => this.broadcastStatusChange(StateChangeType.QualityChanged, quality)
            ],
            [
                "playbackRateChange",
                rate => this.broadcastStatusChange(StateChangeType.RateChanged, rate)
            ],
            [
                "timeupdate",
                time => this.broadcastStatusChange(StateChangeType.PlaybackProgress, time)
            ]
        ]);
    }
    register(player) {
        this.eventHandlers.forEach((eventHandler, eventName) => {
            player.on(eventName, eventHandler);
        });
    }
    broadcastStatusChange(type, payload) {
        this.ngZone.run(() => this.stateChange$.next({ type, payload }));
    }
}
EventsRegistry.ɵprov = ɵɵdefineInjectable({ factory: function EventsRegistry_Factory() { return new EventsRegistry(ɵɵinject(NgZone)); }, token: EventsRegistry, providedIn: YtPlayerAdapterModule });
EventsRegistry.decorators = [
    { type: Injectable, args: [{ providedIn: YtPlayerAdapterModule },] }
];
EventsRegistry.ctorParameters = () => [
    { type: NgZone }
];

class YtPlayerService {
    constructor(eventsRegistry) {
        this.eventsRegistry = eventsRegistry;
    }
    get stateChange$() { return this.eventsRegistry.stateChange$.asObservable(); }
    get destroyed() { return this.player.destroyed; }
    get videoId() { return this.player.videoId; }
    get player() { return this.ytPlayer; }
    set player(value) { this.ytPlayer = value; }
    init(htmlId, playerOptions) {
        this.setUpPlayer(htmlId, playerOptions);
        this.eventsRegistry.register(this.player);
    }
    load(videoId) {
        const autoplay = this.playerOptions && this.playerOptions.autoplay;
        this.player.load(videoId, autoplay);
    }
    play() {
        this.player.play();
    }
    pause() {
        this.player.pause();
    }
    stop() {
        this.player.stop();
    }
    seek(seconds) {
        this.player.seek(seconds);
    }
    setVolume(value) {
        if (value > 100) {
            console.warn(`Provided value ${value} exceeds max value. 100 used instead`);
        }
        this.player.setVolume(value);
    }
    getVolume() {
        return this.player.getVolume();
    }
    mute() {
        this.player.mute();
    }
    unMute() {
        this.player.unMute();
    }
    isMuted() {
        return this.player.isMuted();
    }
    setSize(width, height) {
        this.player.setSize(width, height);
    }
    setPlaybackRate(rate) {
        this.player.setPlaybackRate(rate);
    }
    setPlaybackQuality(sugestedQuality) {
        this.player.setPlaybackQuality(sugestedQuality);
    }
    getPlaybackRate() {
        return this.player.getPlaybackRate();
    }
    getAvailablePlaybackRates() {
        return this.player.getAvailablePlaybackRates();
    }
    getDuration() {
        return this.player.getDuration();
    }
    getBufferingProgress() {
        return this.player.getProgress();
    }
    getState() {
        return this.player.getState();
    }
    getCurrentTime() {
        return this.player.getCurrentTime();
    }
    destroy() {
        this.player.destroy();
    }
    setUpPlayer(htmlId, playerOptions) {
        this.playerOptions = playerOptions;
        this.player = new YtPlayer(htmlId, playerOptions);
    }
}
YtPlayerService.ɵprov = ɵɵdefineInjectable({ factory: function YtPlayerService_Factory() { return new YtPlayerService(ɵɵinject(EventsRegistry)); }, token: YtPlayerService, providedIn: YtPlayerAdapterModule });
YtPlayerService.decorators = [
    { type: Injectable, args: [{ providedIn: YtPlayerAdapterModule },] }
];
YtPlayerService.ctorParameters = () => [
    { type: EventsRegistry }
];

class IdGeneratorService {
    constructor() {
        this.charCodes = { a: 65, z: 90 };
        this.idLength = 8;
    }
    generate() {
        return [...Array(this.idLength).keys()]
            .reduce(acc => `${acc}${this.getRandomLetter()}`, '');
    }
    getRandomLetter() {
        const charCode = this.getRandomIntInRange(this.charCodes.a, this.charCodes.z);
        return String.fromCharCode(charCode);
    }
    getRandomIntInRange(min, max) {
        return Math.floor(Math.random() * (max - min + 1)) + min;
    }
}
IdGeneratorService.ɵprov = ɵɵdefineInjectable({ factory: function IdGeneratorService_Factory() { return new IdGeneratorService(); }, token: IdGeneratorService, providedIn: "root" });
IdGeneratorService.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];

class QueueService {
    constructor() {
        this.queue = new Map();
    }
    enqueue(task) {
        const key = this.generateKey();
        this.addTask(key, task);
    }
    dequeue() {
        const task = this.getAndRemoveFromQueue();
        this.execute(task);
    }
    addTask(key, task) {
        this.queue.set(key, task);
    }
    generateKey() {
        return this.queue.size + 1;
    }
    getAndRemoveFromQueue() {
        const latestKey = this.queue.size;
        const task = this.queue.get(latestKey);
        this.queue.delete(latestKey);
        return task;
    }
    execute(task) {
        if (task && typeof task === 'function') {
            task();
        }
    }
}
QueueService.ɵprov = ɵɵdefineInjectable({ factory: function QueueService_Factory() { return new QueueService(); }, token: QueueService, providedIn: "root" });
QueueService.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];

class YtPlayerComponent {
    constructor(ytPlayerService, idGeneratorService, queueService) {
        this.ytPlayerService = ytPlayerService;
        this.idGeneratorService = idGeneratorService;
        this.queueService = queueService;
        this.stateChange = new EventEmitter();
        this.errorMessage = 'Player not initialized. Did you specify [videoId] input property of yt-player-component?';
    }
    ngOnInit() {
        this.setUpElementRefId();
        this.dequeuePlayerInitialization();
        this.loadVideo();
        this.subscribeToStateChanges();
    }
    ngOnChanges() {
        if (!this.videoIdIsDefined()) {
            return;
        }
        else if (this.elementRefIdIsDefined()) {
            this.reloadVideo();
        }
        else {
            this.enqueuePlayerInitialization();
        }
    }
    ngOnDestroy() {
        this.ytPlayerService.destroy();
        this.stateChangeSubscription.unsubscribe();
    }
    setUpElementRefId() {
        const id = this.idGeneratorService.generate();
        this.ytHtmlElementHook.nativeElement.setAttribute('id', id);
    }
    videoIdIsDefined() {
        return !!this.videoId;
    }
    elementRefIdIsDefined() {
        return (this.ytHtmlElementHook.nativeElement &&
            this.ytHtmlElementHook.nativeElement.getAttribute('id'));
    }
    initializePlayer() {
        const id = this.ytHtmlElementHook.nativeElement.getAttribute('id');
        this.ytPlayerService.init(`#${id}`, this.options);
    }
    loadVideo() {
        try {
            this.ytPlayerService.load(this.videoId);
        }
        catch (err) {
            console.error(this.errorMessage);
        }
    }
    reloadVideo() {
        this.ytPlayerService.destroy();
        this.initializePlayer();
        this.loadVideo();
    }
    enqueuePlayerInitialization() {
        this.queueService.enqueue(() => this.initializePlayer());
    }
    dequeuePlayerInitialization() {
        this.queueService.dequeue();
    }
    subscribeToStateChanges() {
        this.stateChangeSubscription = this.ytPlayerService.stateChange$.subscribe(stateChange => this.stateChange.emit(stateChange));
    }
}
YtPlayerComponent.decorators = [
    { type: Component, args: [{
                selector: 'yt-player',
                template: `
    <div #ytHtmlElementHook></div>
  `
            },] }
];
YtPlayerComponent.ctorParameters = () => [
    { type: YtPlayerService },
    { type: IdGeneratorService },
    { type: QueueService }
];
YtPlayerComponent.propDecorators = {
    videoId: [{ type: Input }],
    options: [{ type: Input }],
    stateChange: [{ type: Output }],
    ytHtmlElementHook: [{ type: ViewChild, args: ['ytHtmlElementHook', { static: true },] }]
};

class YtPlayerAngularModule {
}
YtPlayerAngularModule.decorators = [
    { type: NgModule, args: [{
                imports: [YtPlayerAdapterModule],
                declarations: [YtPlayerComponent],
                exports: [YtPlayerComponent]
            },] }
];

var PlayerState;
(function (PlayerState) {
    PlayerState[PlayerState["Unstarted"] = 0] = "Unstarted";
    PlayerState[PlayerState["Ended"] = 1] = "Ended";
    PlayerState[PlayerState["Playing"] = 2] = "Playing";
    PlayerState[PlayerState["Paused"] = 3] = "Paused";
    PlayerState[PlayerState["Buffering"] = 4] = "Buffering";
    PlayerState[PlayerState["Cued"] = 5] = "Cued";
})(PlayerState || (PlayerState = {}));

var PlaybackQuality;
(function (PlaybackQuality) {
    PlaybackQuality["Small"] = "small";
    PlaybackQuality["Medium"] = "medium";
    PlaybackQuality["Large"] = "large";
    PlaybackQuality["Hd720"] = "hd720";
    PlaybackQuality["Hd1080"] = "hd1080";
    PlaybackQuality["HighRes"] = "highres";
    PlaybackQuality["Default"] = "default";
})(PlaybackQuality || (PlaybackQuality = {}));

/*
 * Public API Surface of yt-player-angular
 */

/**
 * Generated bundle index. Do not edit.
 */

export { PlaybackQuality, PlayerState, StateChangeType, YtPlayerAngularModule, YtPlayerComponent, YtPlayerService, YtPlayerAdapterModule as ɵa, EventsRegistry as ɵb, IdGeneratorService as ɵc, QueueService as ɵd };
//# sourceMappingURL=yt-player-angular.js.map
